==> okteta_0.25.5.orig.tar.xz: okteta-0.25.5/kasten/controllers/view/structures/structtoolview.h <==
/*
 *   This file is part of the Okteta Kasten Framework, made within the KDE community.
 *
 *   Copyright 2009, 2010 Alex Richardson <alex.richardson@gmx.de>
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) version 3, or any
 *   later version accepted by the membership of KDE e.V. (or its
 *   successor approved by the membership of KDE e.V.), which shall
 *   act as a proxy defined in Section 6 of version 3 of the license.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef STRUCTTOOLVIEW_H_
#define STRUCTTOOLVIEW_H_
// lib
#include <kasten/okteta/oktetakastencontrollers_export.h>

// Kasten gui
#include <kasten/abstracttoolview.h>

namespace Kasten {
class StructView;
class StructTool;

class OKTETAKASTENCONTROLLERS_EXPORT StructToolView : public AbstractToolView
{
public:
    explicit StructToolView(StructTool* tool);
    ~StructToolView() override;

public:
    // AbstractToolView API
    QWidget* widget() const override;
    QString title() const override;
    AbstractTool* tool() const override;

protected:
    StructView* mWidget;
};

}
#endif /* STRUCTTOOLVIEW_H_ */

==> okteta-14.12.3.tar.xz: okteta-14.12.3/kasten/controllers/view/structures/structtoolview.h <==
/*
 *   This file is part of the Okteta Kasten Framework, made within the KDE community.
 *
 *   Copyright 2009, 2010 Alex Richardson <alex.richardson@gmx.de>
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) version 3, or any
 *   later version accepted by the membership of KDE e.V. (or its
 *   successor approved by the membership of KDE e.V.), which shall
 *   act as a proxy defined in Section 6 of version 3 of the license.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef STRUCTTOOLVIEW_H_
#define STRUCTTOOLVIEW_H_
// lib
#include "oktetakastencontrollers_export.h"

// Kasten gui
#include <abstracttoolview.h>

namespace Kasten
{
class StructView;
class StructTool;

class OKTETAKASTENCONTROLLERS_EXPORT StructToolView: public AbstractToolView
{
public:
    explicit StructToolView(StructTool *tool);
    virtual ~StructToolView();

public:
    // AbstractToolView API
    virtual QWidget* widget() const;
    virtual QString title() const;
    virtual AbstractTool* tool() const;

protected:
    StructView* mWidget;
};

}
#endif /* STRUCTTOOLVIEW_H_ */
